﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Routing;
using Microsoft.Docs.Samples;

namespace TestProject.Controllers
{
    /// <summary>
    /// 테스트 컨트롤러
    /// </summary>
    public class TestController : Controller
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 링크 발생기
        /// </summary>
        private readonly LinkGenerator linkGenerator;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - TestController(linkGenerator)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="linkGenerator">링크 발생기</param>
        public TestController(LinkGenerator linkGenerator)
        {
            this.linkGenerator = linkGenerator;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 인덱스 페이지 처리하기 - Index()

        /// <summary>
        /// 인덱스 페이지 처리하기
        /// </summary>
        /// <returns>액션 결과</returns>
        public IActionResult Index()
        {
            string url = this.linkGenerator.GetPathByAction(HttpContext, null, null, new { id = 17, });

            return Content(url);
        }

        #endregion
        #region 구독 페이지 처리하기 - Subscribe(id)

        /// <summary>
        /// 구독 페이지 처리하기
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>액션 결과</returns>
        public IActionResult Subscribe(int id) => ControllerContext.MyDisplayRouteInfo(id);

        #endregion
        #region 작성 페이지 처리하기 - Write()

        /// <summary>
        /// 작성 페이지 처리하기
        /// </summary>
        /// <returns>액션 결과</returns>
        public IActionResult Write()
        {
            string url = this.linkGenerator.GetPathByAction("Subscribe", "Home", new { id = 17 });

            return Content(url);
        }

        #endregion
    }
}